@@ -1,4 +1,4 @@
 """contains some default parameters of the application."""
 
-SMARTPHONE_ID = 'pymultiMATIC'
+SMARTPHONE_ID = "pymultiMATIC"
 """Default smartphone id."""
